@@ -32,6 +32,8 @@
  * Original Author:  David Gilbert (for Object Refinery Limited);
  * Contributor(s):   Pierre-Marie Le Biot;
  *
+ * $Id: LegendTitle.java,v 1.20.2.10 2007/03/20 08:31:20 mungady Exp $
+ *
  * Changes
  * -------
  * 25-Nov-2004 : First working version (DG);
@@ -52,7 +54,6 @@
  * 06-Oct-2006 : Add tooltip and URL text to legend item (DG);
  * 13-Dec-2006 : Added support for GradientPaint in legend items (DG);
  * 16-Mar-2007 : Updated border drawing for changes in AbstractBlock (DG);
- * 18-May-2007 : Pass seriesKey and dataset to legend item block (DG);
  * 
  */
 
@@ -142,16 +143,8 @@ public class LegendTitle extends Title
      */
     private BlockContainer items;
     
-    /** 
-     * The layout for the legend when it is positioned at the top or bottom
-     * of the chart.
-     */
     private Arrangement hLayout;
     
-    /** 
-     * The layout for the legend when it is positioned at the left or right
-     * of the chart.
-     */
     private Arrangement vLayout;
     
     /** 
@@ -436,8 +429,8 @@ public class LegendTitle extends Title
         lg.setPadding(this.legendItemGraphicPadding);
 
         LegendItemBlockContainer legendItem = new LegendItemBlockContainer(
-                new BorderArrangement(), item.getDataset(), 
-                item.getSeriesKey());
+                new BorderArrangement(), item.getDatasetIndex(), 
+                item.getSeriesIndex());
         lg.setShapeAnchor(getLegendItemGraphicAnchor());
         lg.setShapeLocation(getLegendItemGraphicLocation());
         legendItem.add(lg, this.legendItemGraphicEdge);
